[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[no subject]
From: |
Patrice Dumas |
Date: |
Mon, 20 May 2024 08:27:53 -0400 (EDT) |
branch: master
commit 8e9f85fff1a37872aa2d6279f4ac72baf754fead
Author: Patrice Dumas <pertusus@free.fr>
AuthorDate: Mon May 20 13:23:04 2024 +0200
* tp/Texinfo/XS/parsetexi/conf.h (parser_conf): rename conf as
parser_conf. Update users.
---
ChangeLog | 5 ++
tp/Texinfo/XS/parsetexi/api.c | 12 ++--
tp/Texinfo/XS/parsetexi/commands.c | 2 +-
tp/Texinfo/XS/parsetexi/conf.c | 98 +++++++++++++++----------------
tp/Texinfo/XS/parsetexi/conf.h | 2 +-
tp/Texinfo/XS/parsetexi/debug_parser.c | 12 ++--
tp/Texinfo/XS/parsetexi/end_line.c | 12 ++--
tp/Texinfo/XS/parsetexi/errors_parser.c | 2 +-
tp/Texinfo/XS/parsetexi/handle_commands.c | 4 +-
tp/Texinfo/XS/parsetexi/indices.c | 2 +-
tp/Texinfo/XS/parsetexi/input.c | 13 ++--
tp/Texinfo/XS/parsetexi/macro.c | 20 +++----
tp/Texinfo/XS/parsetexi/menus.c | 4 +-
tp/Texinfo/XS/parsetexi/parser.c | 19 +++---
14 files changed, 107 insertions(+), 100 deletions(-)
diff --git a/ChangeLog b/ChangeLog
index 2ac200b5c9..4e7a6025bf 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+2024-05-20 Patrice Dumas <pertusus@free.fr>
+
+ * tp/Texinfo/XS/parsetexi/conf.h (parser_conf): rename conf as
+ parser_conf. Update users.
+
2024-05-20 Patrice Dumas <pertusus@free.fr>
Set remaining configuration vaiables in CONF
diff --git a/tp/Texinfo/XS/parsetexi/api.c b/tp/Texinfo/XS/parsetexi/api.c
index 14d699d293..24016976d0 100644
--- a/tp/Texinfo/XS/parsetexi/api.c
+++ b/tp/Texinfo/XS/parsetexi/api.c
@@ -41,7 +41,7 @@
/* for wipe_macros store_value init_values wipe_values */
#include "macro.h"
#include "document.h"
-/* for reset_conf conf_add_include_directory */
+/* for reset_conf */
#include "conf.h"
/* for init_index_commands */
#include "indices.h"
@@ -58,8 +58,8 @@ initialize_parsing (void)
init_values ();
free (global_documentlanguage);
- if (conf.global_documentlanguage_fixed && conf.documentlanguage)
- global_documentlanguage = strdup (conf.documentlanguage);
+ if (parser_conf.global_documentlanguage_fixed &&
parser_conf.documentlanguage)
+ global_documentlanguage = strdup (parser_conf.documentlanguage);
else
global_documentlanguage = 0;
@@ -84,7 +84,7 @@ initialize_parsing (void)
reset_obstacks ();
- if (!conf.no_index)
+ if (!parser_conf.no_index)
init_index_commands ();
set_input_encoding ("utf-8");
@@ -211,12 +211,12 @@ parse_piece (const char *string, int line_nr)
void
parser_reset_values_conf (void)
{
- wipe_values (&conf.values);
+ wipe_values (&parser_conf.values);
}
void
parser_store_value (const char *name, const char *value)
{
- store_value (&conf.values, name, value);
+ store_value (&parser_conf.values, name, value);
}
diff --git a/tp/Texinfo/XS/parsetexi/commands.c
b/tp/Texinfo/XS/parsetexi/commands.c
index 9423fa1748..3a3bf9ff1a 100644
--- a/tp/Texinfo/XS/parsetexi/commands.c
+++ b/tp/Texinfo/XS/parsetexi/commands.c
@@ -54,7 +54,7 @@ lookup_command (char *cmdname)
/* txiinternalvalue is invalid if the corresponding parameter
* is not set */
- if (cmd == CM_txiinternalvalue && !conf.accept_internalvalue)
+ if (cmd == CM_txiinternalvalue && !parser_conf.accept_internalvalue)
return 0;
return cmd;
diff --git a/tp/Texinfo/XS/parsetexi/conf.c b/tp/Texinfo/XS/parsetexi/conf.c
index 201f39e7b5..71ae00c16e 100644
--- a/tp/Texinfo/XS/parsetexi/conf.c
+++ b/tp/Texinfo/XS/parsetexi/conf.c
@@ -22,150 +22,150 @@
#include "conf.h"
/* Configuration values. */
-CONF conf;
+CONF parser_conf;
void
conf_set_show_menu (int i)
{
- conf.show_menu = i;
+ parser_conf.show_menu = i;
}
void
conf_set_CPP_LINE_DIRECTIVES (int i)
{
- conf.cpp_line_directives = i;
+ parser_conf.cpp_line_directives = i;
}
void
conf_set_IGNORE_SPACE_AFTER_BRACED_COMMAND_NAME (int i)
{
- conf.ignore_space_after_braced_command_name = i;
+ parser_conf.ignore_space_after_braced_command_name = i;
}
void
conf_set_MAX_MACRO_CALL_NESTING (int i)
{
- conf.max_macro_call_nesting = i;
+ parser_conf.max_macro_call_nesting = i;
}
int
conf_set_NO_INDEX (int i)
{
- int previous = conf.no_index;
- conf.no_index = i;
+ int previous = parser_conf.no_index;
+ parser_conf.no_index = i;
return previous;
}
int
conf_set_NO_USER_COMMANDS (int i)
{
- int previous = conf.no_user_commands;
- conf.no_user_commands = i;
+ int previous = parser_conf.no_user_commands;
+ parser_conf.no_user_commands = i;
return previous;
}
int
conf_set_DEBUG (int i)
{
- int previous = conf.debug;
- conf.debug = i;
+ int previous = parser_conf.debug;
+ parser_conf.debug = i;
return previous;
}
void
conf_clear_INCLUDE_DIRECTORIES (void)
{
- clear_strings_list (&conf.include_directories);
+ clear_strings_list (&parser_conf.include_directories);
}
void
conf_add_include_directory (const char *filename)
{
- add_include_directory (filename, &conf.include_directories);
+ add_include_directory (filename, &parser_conf.include_directories);
}
void
conf_clear_expanded_formats (void)
{
- clear_expanded_formats (conf.expanded_formats);
+ clear_expanded_formats (parser_conf.expanded_formats);
}
void
conf_add_expanded_format (const char *format)
{
- add_expanded_format (conf.expanded_formats, format);
+ add_expanded_format (parser_conf.expanded_formats, format);
}
void
conf_set_documentlanguage (const char *value)
{
- free (conf.documentlanguage);
- conf.documentlanguage = value ? strdup (value) : 0;
- conf.global_documentlanguage_fixed = 1;
+ free (parser_conf.documentlanguage);
+ parser_conf.documentlanguage = value ? strdup (value) : 0;
+ parser_conf.global_documentlanguage_fixed = 1;
}
void
conf_set_DOC_ENCODING_FOR_INPUT_FILE_NAME (int i)
{
- conf.doc_encoding_for_input_file_name = i;
+ parser_conf.doc_encoding_for_input_file_name = i;
}
void
conf_set_INPUT_FILE_NAME_ENCODING (const char *value)
{
- free (conf.input_file_name_encoding);
- conf.input_file_name_encoding = value ? strdup (value) : 0;
+ free (parser_conf.input_file_name_encoding);
+ parser_conf.input_file_name_encoding = value ? strdup (value) : 0;
}
void
conf_set_LOCALE_ENCODING (const char *value)
{
- free (conf.locale_encoding);
- conf.locale_encoding = value ? strdup (value) : 0;
+ free (parser_conf.locale_encoding);
+ parser_conf.locale_encoding = value ? strdup (value) : 0;
}
void
conf_set_accept_internalvalue (int value)
{
- conf.accept_internalvalue = value;
+ parser_conf.accept_internalvalue = value;
}
void
reset_conf (void)
{
- wipe_values (&conf.values);
- clear_strings_list (&conf.include_directories);
- free (conf.documentlanguage);
- free (conf.input_file_name_encoding);
- free (conf.locale_encoding);
-
- conf.accept_internalvalue = 0;
- conf.cpp_line_directives = 1;
- conf.debug = 1;
- conf.doc_encoding_for_input_file_name = 1;
- conf.documentlanguage = 0;
- conf.ignore_space_after_braced_command_name = 1;
- conf.input_file_name_encoding = 0;
- conf.locale_encoding = 0;
- conf.max_macro_call_nesting = 100000;
- conf.no_index = 0;
- conf.no_user_commands = 0;
- conf.show_menu = 1;
-
- conf.global_documentlanguage_fixed = 0;
-
- memcpy (conf.expanded_formats, default_expanded_formats,
- sizeof (conf.expanded_formats));
+ wipe_values (&parser_conf.values);
+ clear_strings_list (&parser_conf.include_directories);
+ free (parser_conf.documentlanguage);
+ free (parser_conf.input_file_name_encoding);
+ free (parser_conf.locale_encoding);
+
+ parser_conf.accept_internalvalue = 0;
+ parser_conf.cpp_line_directives = 1;
+ parser_conf.debug = 1;
+ parser_conf.doc_encoding_for_input_file_name = 1;
+ parser_conf.documentlanguage = 0;
+ parser_conf.ignore_space_after_braced_command_name = 1;
+ parser_conf.input_file_name_encoding = 0;
+ parser_conf.locale_encoding = 0;
+ parser_conf.max_macro_call_nesting = 100000;
+ parser_conf.no_index = 0;
+ parser_conf.no_user_commands = 0;
+ parser_conf.show_menu = 1;
+
+ parser_conf.global_documentlanguage_fixed = 0;
+
+ memcpy (parser_conf.expanded_formats, default_expanded_formats,
+ sizeof (parser_conf.expanded_formats));
/* It would have been cleaner to separate setting default values,
but it is not needed, as default_expanded_formats is already zeros,
so the call can be kept in comments
conf_clear_expanded_formats ();
*/
- add_include_directory (".", &conf.include_directories);
+ add_include_directory (".", &parser_conf.include_directories);
/* special value always returned as 1 to mark that @ifcommandnotdefined
is implemented. Note that when called from the main program it is set
from Perl using the configuration passed to the parser */
- store_value (&conf.values, "txicommandconditionals", "1");
+ store_value (&parser_conf.values, "txicommandconditionals", "1");
}
diff --git a/tp/Texinfo/XS/parsetexi/conf.h b/tp/Texinfo/XS/parsetexi/conf.h
index 191bf49736..a11d720f1a 100644
--- a/tp/Texinfo/XS/parsetexi/conf.h
+++ b/tp/Texinfo/XS/parsetexi/conf.h
@@ -39,7 +39,7 @@ typedef struct CONF {
VALUE_LIST values;
} CONF;
-extern CONF conf;
+extern CONF parser_conf;
/* part of public API */
void conf_set_show_menu (int i);
diff --git a/tp/Texinfo/XS/parsetexi/end_line.c
b/tp/Texinfo/XS/parsetexi/end_line.c
index 52ed37c7d9..75d89d500e 100644
--- a/tp/Texinfo/XS/parsetexi/end_line.c
+++ b/tp/Texinfo/XS/parsetexi/end_line.c
@@ -132,7 +132,7 @@ parse_line_command_args (ELEMENT *line_command)
{
case CM_alias:
{
- if (conf.no_user_commands)
+ if (parser_conf.no_user_commands)
break;
/* @alias NEW = EXISTING */
char *new = 0, *existing = 0;
@@ -211,7 +211,7 @@ parse_line_command_args (ELEMENT *line_command)
}
case CM_definfoenclose:
{
- if (conf.no_user_commands)
+ if (parser_conf.no_user_commands)
break;
/* @definfoenclose phoo,//,\\ */
@@ -334,7 +334,7 @@ parse_line_command_args (ELEMENT *line_command)
case CM_defindex:
case CM_defcodeindex:
{
- if (conf.no_user_commands || conf.no_index)
+ if (parser_conf.no_user_commands || parser_conf.no_index)
break;
char *name = 0;
@@ -402,7 +402,7 @@ parse_line_command_args (ELEMENT *line_command)
if (*p)
goto synindex_invalid; /* More at end of line. */
- if (conf.no_index)
+ if (parser_conf.no_index)
{
free (index_name_from);
free (index_name_to);
@@ -458,7 +458,7 @@ parse_line_command_args (ELEMENT *line_command)
arg = read_command_name (&p);
if (!arg || *p)
line_error ("bad argument to @printindex: %s", line);
- else if (conf.no_index)
+ else if (parser_conf.no_index)
{}
else
{
@@ -1520,7 +1520,7 @@ end_line_misc_line (ELEMENT *current)
}
}
/* Set the document language unless it was set on the command line.
*/
- if (!conf.global_documentlanguage_fixed)
+ if (!parser_conf.global_documentlanguage_fixed)
{
free (global_documentlanguage);
global_documentlanguage = strdup (text);
diff --git a/tp/Texinfo/XS/parsetexi/errors_parser.c
b/tp/Texinfo/XS/parsetexi/errors_parser.c
index 0f81b69ef8..c2b99c0bab 100644
--- a/tp/Texinfo/XS/parsetexi/errors_parser.c
+++ b/tp/Texinfo/XS/parsetexi/errors_parser.c
@@ -42,7 +42,7 @@ line_error_internal (enum error_type type, int continuation,
const char *format, va_list v)
{
vmessage_list_line_error (&parsed_document->parser_error_messages,
- type, continuation, conf.debug, cmd_source_info,
+ type, continuation, parser_conf.debug, cmd_source_info,
0, format, v);
}
diff --git a/tp/Texinfo/XS/parsetexi/handle_commands.c
b/tp/Texinfo/XS/parsetexi/handle_commands.c
index cf9d55e8c9..082d960421 100644
--- a/tp/Texinfo/XS/parsetexi/handle_commands.c
+++ b/tp/Texinfo/XS/parsetexi/handle_commands.c
@@ -984,7 +984,7 @@ funexit:
int
parser_format_expanded_p (const char *format)
{
- return format_expanded_p (conf.expanded_formats, format);
+ return format_expanded_p (parser_conf.expanded_formats, format);
}
/* A command name has been read that starts a multiline block, which should
@@ -1092,7 +1092,7 @@ handle_block_command (ELEMENT *current, char **line_inout,
if (current_node)
{
- if (cmd == CM_direntry && conf.show_menu)
+ if (cmd == CM_direntry && parser_conf.show_menu)
{
line_warn ("@direntry after first node");
}
diff --git a/tp/Texinfo/XS/parsetexi/indices.c
b/tp/Texinfo/XS/parsetexi/indices.c
index fee42cb115..f90e270bf5 100644
--- a/tp/Texinfo/XS/parsetexi/indices.c
+++ b/tp/Texinfo/XS/parsetexi/indices.c
@@ -244,7 +244,7 @@ enter_index_entry (enum command_id index_type_cmd,
const IGNORED_CHARS *ignored_chars_info
= &parsed_document->global_info.ignored_chars;
- if (conf.no_index)
+ if (parser_conf.no_index)
return;
idx = index_of_command (index_type_cmd);
diff --git a/tp/Texinfo/XS/parsetexi/input.c b/tp/Texinfo/XS/parsetexi/input.c
index 906ac500d7..db10f197c3 100644
--- a/tp/Texinfo/XS/parsetexi/input.c
+++ b/tp/Texinfo/XS/parsetexi/input.c
@@ -178,11 +178,12 @@ encode_file_name (char *filename)
{
if (!reverse_iconv)
{
- if (conf.input_file_name_encoding)
+ if (parser_conf.input_file_name_encoding)
{
- reverse_iconv = iconv_open (conf.input_file_name_encoding, "UTF-8");
+ reverse_iconv
+ = iconv_open (parser_conf.input_file_name_encoding, "UTF-8");
}
- else if (conf.doc_encoding_for_input_file_name)
+ else if (parser_conf.doc_encoding_for_input_file_name)
{
if (current_encoding_conversion
&& strcmp (parsed_document->global_info.input_encoding_name,
@@ -193,9 +194,9 @@ encode_file_name (char *filename)
reverse_iconv = iconv_open (conversion_encoding, "UTF-8");
}
}
- else if (conf.locale_encoding)
+ else if (parser_conf.locale_encoding)
{
- reverse_iconv = iconv_open (conf.locale_encoding, "UTF-8");
+ reverse_iconv = iconv_open (parser_conf.locale_encoding, "UTF-8");
}
}
if (reverse_iconv && reverse_iconv != (iconv_t) -1)
@@ -541,7 +542,7 @@ top_file_index (void)
char *
parser_locate_include_file (const char *filename)
{
- return locate_include_file (filename, &conf.include_directories);
+ return locate_include_file (filename, &parser_conf.include_directories);
}
/* Try to open a file called FILENAME */
diff --git a/tp/Texinfo/XS/parsetexi/macro.c b/tp/Texinfo/XS/parsetexi/macro.c
index b98a0d4f31..809442bb8b 100644
--- a/tp/Texinfo/XS/parsetexi/macro.c
+++ b/tp/Texinfo/XS/parsetexi/macro.c
@@ -70,7 +70,7 @@ new_macro (char *name, ELEMENT *macro)
MACRO *m = 0;
size_t free_slot = 0;
- if (conf.no_user_commands)
+ if (parser_conf.no_user_commands)
return;
/* Check for an existing definition first for us to overwrite. */
@@ -568,7 +568,7 @@ expand_linemacro_arguments (ELEMENT *macro, char
**line_inout,
if (cmd && (command_data(cmd).flags & CF_brace)
&& strchr (whitespace_chars, *pline)
&& ((command_flags(current) & CF_accent)
- || conf.ignore_space_after_braced_command_name))
+ || parser_conf.ignore_space_after_braced_command_name))
{
int whitespaces_len = strspn (pline, whitespace_chars);
text_append_n (arg, pline, whitespaces_len);
@@ -847,13 +847,13 @@ handle_macro (ELEMENT *current, char **line_inout, enum
command_id cmd)
}
}
- if (conf.max_macro_call_nesting
- && macro_expansion_nr > conf.max_macro_call_nesting)
+ if (parser_conf.max_macro_call_nesting
+ && macro_expansion_nr > parser_conf.max_macro_call_nesting)
{
line_warn (
"macro call nested too deeply "
"(set MAX_MACRO_CALL_NESTING to override; current value %d)",
- conf.max_macro_call_nesting);
+ parser_conf.max_macro_call_nesting);
error = 1;
}
@@ -1029,15 +1029,15 @@ init_values (void)
wipe_values (&parser_values);
- if (parser_values.space < conf.values.number)
+ if (parser_values.space < parser_conf.values.number)
{
- parser_values.space = conf.values.number;
+ parser_values.space = parser_conf.values.number;
parser_values.list = realloc (parser_values.list,
parser_values.space * sizeof (VALUE));
}
- for (i = 0; i < conf.values.number; i++)
- store_value (&parser_values, conf.values.list[i].name,
- conf.values.list[i].value);
+ for (i = 0; i < parser_conf.values.number; i++)
+ store_value (&parser_values, parser_conf.values.list[i].name,
+ parser_conf.values.list[i].value);
}
void
diff --git a/tp/Texinfo/XS/parsetexi/menus.c b/tp/Texinfo/XS/parsetexi/menus.c
index 79b4b9bbb2..5562f64bb5 100644
--- a/tp/Texinfo/XS/parsetexi/menus.c
+++ b/tp/Texinfo/XS/parsetexi/menus.c
@@ -29,7 +29,7 @@
#include "manipulate_tree.h"
#include "input.h"
#include "text.h"
-/* for conf */
+/* for parser_conf */
#include "conf.h"
#include "convert_to_texinfo.h"
#include "labels.h"
@@ -66,7 +66,7 @@ register_extra_menu_entry_information (ELEMENT *current)
if (!parsed_entry_node->manual_content
&& !parsed_entry_node->node_content)
{
- if (conf.show_menu)
+ if (parser_conf.show_menu)
line_error ("empty node name in menu entry");
}
else
diff --git a/tp/Texinfo/XS/parsetexi/parser.c b/tp/Texinfo/XS/parsetexi/parser.c
index fa961e8e39..0cb039deb6 100644
--- a/tp/Texinfo/XS/parsetexi/parser.c
+++ b/tp/Texinfo/XS/parsetexi/parser.c
@@ -37,7 +37,7 @@
#include "input.h"
#include "source_marks.h"
#include "extra.h"
-/* for conf */
+/* for parser_conf */
#include "conf.h"
#include "command_stack.h"
/* for nesting_context */
@@ -1774,7 +1774,7 @@ process_remaining_on_line (ELEMENT **current_inout, char
**line_inout)
{
char *remaining_line = line_after_command;
ELEMENT *spaces_element = 0;
- if (conf.ignore_space_after_braced_command_name)
+ if (parser_conf.ignore_space_after_braced_command_name)
{
int whitespaces_len = strspn (remaining_line, whitespace_chars);
if (whitespaces_len > 0)
@@ -1804,13 +1804,14 @@ process_remaining_on_line (ELEMENT **current_inout,
char **line_inout)
ELEMENT *sm_value_element;
remaining_line++; /* past '}' */
- if (conf.max_macro_call_nesting
- && value_expansion_nr >= conf.max_macro_call_nesting)
+ if (parser_conf.max_macro_call_nesting
+ && value_expansion_nr
+ >= parser_conf.max_macro_call_nesting)
{
line_warn (
"value call nested too deeply "
"(set MAX_MACRO_CALL_NESTING to override; current value
%d)",
- conf.max_macro_call_nesting);
+ parser_conf.max_macro_call_nesting);
free (flag);
if (spaces_element)
destroy_element (spaces_element);
@@ -1943,7 +1944,7 @@ process_remaining_on_line (ELEMENT **current_inout, char
**line_inout)
if (strchr (whitespace_chars, *line)
&& ((command_flags(current) & CF_accent)
- || conf.ignore_space_after_braced_command_name))
+ || parser_conf.ignore_space_after_braced_command_name))
{
int whitespaces_len;
int additional_newline = 0;
@@ -2096,7 +2097,7 @@ process_remaining_on_line (ELEMENT **current_inout, char
**line_inout)
char *arg_start;
char *flag;
ELEMENT *spaces_element = 0;
- if (conf.ignore_space_after_braced_command_name)
+ if (parser_conf.ignore_space_after_braced_command_name)
{
int whitespaces_len = strspn (line, whitespace_chars);
if (whitespaces_len > 0)
@@ -2437,7 +2438,7 @@ check_line_directive (char *line)
int status = 0;
char *parsed_filename;
- if (!conf.cpp_line_directives)
+ if (!parser_conf.cpp_line_directives)
return 0;
/* Check input is coming directly from a file. */
@@ -2625,7 +2626,7 @@ parse_texi (ELEMENT *root_elt, ELEMENT *current_elt)
parsed_document = 0;
forget_indices ();
- complete_indices (document, conf.debug);
+ complete_indices (document, parser_conf.debug);
return document->descriptor;
}
diff --git a/tp/Texinfo/XS/parsetexi/debug_parser.c
b/tp/Texinfo/XS/parsetexi/debug_parser.c
index 72d588ea41..81e156a18f 100644
--- a/tp/Texinfo/XS/parsetexi/debug_parser.c
+++ b/tp/Texinfo/XS/parsetexi/debug_parser.c
@@ -25,14 +25,14 @@
#include "conf.h"
#include "debug_parser.h"
/* debug functions used in parser, depending on conf.debug */
void
debug (char *s, ...)
{
va_list v;
- if (!conf.debug)
+ if (!parser_conf.debug)
return;
va_start (v, s);
vfprintf (stderr, s, v);
@@ -44,7 +44,7 @@ debug_nonl (char *s, ...)
{
va_list v;
- if (!conf.debug)
+ if (!parser_conf.debug)
return;
va_start (v, s);
vfprintf (stderr, s, v);
@@ -53,7 +53,7 @@ debug_nonl (char *s, ...)
void
debug_print_element (const ELEMENT *e, int print_parent)
{
- if (conf.debug)
+ if (parser_conf.debug)
{
char *result;
result = print_element_debug (e, print_parent);
@@ -65,7 +65,7 @@ debug_print_element (const ELEMENT *e, int print_parent)
void
debug_print_protected_string (char *input_string)
{
- if (conf.debug)
+ if (parser_conf.debug)
{
int allocated = 0;
char *result = debug_protect_eol (input_string, &allocated);
@@ -133,7 +133,7 @@ print_element_debug_parser (ELEMENT *e, int print_parent)
void
debug_parser_print_element (ELEMENT *e, int print_parent)
{
- if (conf.debug)
+ if (parser_conf.debug)
{
char *result;
result = print_element_debug_parser (e, print_parent);
@@ -25,14 +25,14 @@
#include "conf.h"
#include "debug_parser.h"
-/* debug functions used in parser, depending on conf.debug */
+/* debug functions used in parser, depending on parser_conf.debug */
void
debug (char *s, ...)